==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEngineFindTextResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginefindtextresult.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineFindTextResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineFindTextResult")
    QWebEngineFindTextResult *_ptr = reinterpret_cast<QWebEngineFindTextResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineFindTextResult()
void __qt_construct_QWebEngineFindTextResult(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineFindTextResult()")
    Q_UNUSED(__java_arguments)
    QWebEngineFindTextResult *__qt_this = new(__qtjambi_ptr) QWebEngineFindTextResult();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QWebEngineFindTextResult::QWebEngineFindTextResult()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_initialize_1native__Lio_qt_webengine_core_QWebEngineFindTextResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineFindTextResult::QWebEngineFindTextResult()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineFindTextResult, sizeof(QWebEngineFindTextResult), typeid(QWebEngineFindTextResult), false, &deleter_QWebEngineFindTextResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QWebEngineFindTextResult(QWebEngineFindTextResult)
void __qt_construct_QWebEngineFindTextResult_cref_QWebEngineFindTextResult(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineFindTextResult(QWebEngineFindTextResult)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineFindTextResult& __qt_other0 = qtjambi_cast<const QWebEngineFindTextResult& >(__jni_env, other0);
    QWebEngineFindTextResult *__qt_this = new(__qtjambi_ptr) QWebEngineFindTextResult(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWebEngineFindTextResult::QWebEngineFindTextResult(QWebEngineFindTextResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_initialize_1native__Lio_qt_webengine_core_QWebEngineFindTextResult_2Lio_qt_webengine_core_QWebEngineFindTextResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineFindTextResult::QWebEngineFindTextResult(QWebEngineFindTextResult)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineFindTextResult_cref_QWebEngineFindTextResult, sizeof(QWebEngineFindTextResult), typeid(QWebEngineFindTextResult), false, &deleter_QWebEngineFindTextResult, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWebEngineFindTextResult
void __qt_destruct_QWebEngineFindTextResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineFindTextResult")
    reinterpret_cast<QWebEngineFindTextResult*>(ptr)->~QWebEngineFindTextResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineFindTextResult::activeMatch()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_activeMatch_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::activeMatch()const", __qt_this)
        __java_return_value = __qt_this->activeMatch();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFindTextResult::numberOfMatches()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_numberOfMatches_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::numberOfMatches()const", __qt_this)
        __java_return_value = __qt_this->numberOfMatches();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFindTextResult::operator=(QWebEngineFindTextResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_assign_1native_1cref_1QWebEngineFindTextResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::operator=(QWebEngineFindTextResult)", __qt_this)
        const QWebEngineFindTextResult& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineFindTextResult>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFindTextResult::operator==(QWebEngineFindTextResult,QWebEngineFindTextResult)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_equals_1native_1cref_1QWebEngineFindTextResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::operator==(QWebEngineFindTextResult,QWebEngineFindTextResult)", __qt_this)
        const QWebEngineFindTextResult& __qt_arg21 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineFindTextResult>(arg21);
        __java_return_value = (*__qt_this) == __qt_arg21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineFindTextResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineFindTextResult>("QWebEngineFindTextResult", "io/qt/webengine/core/QWebEngineFindTextResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineFindTextResult, {
        ConstructorInfo(&__qt_construct_QWebEngineFindTextResult, nullptr)
       ,ConstructorInfo(&__qt_construct_QWebEngineFindTextResult_cref_QWebEngineFindTextResult, "Lio/qt/webengine/core/QWebEngineFindTextResult;")
    });
// END: function table

    registerMetaObject(typeId, QWebEngineFindTextResult::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineFindTextResult);
    registerMetaType<QWebEngineFindTextResult>("QWebEngineFindTextResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiWebEngineCore/QWebEngineFindTextResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginefindtextresult.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineFindTextResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineFindTextResult")
    QWebEngineFindTextResult *_ptr = reinterpret_cast<QWebEngineFindTextResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineFindTextResult()
void __qt_construct_QWebEngineFindTextResult_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineFindTextResult()")
    Q_UNUSED(__java_arguments)
    QWebEngineFindTextResult *__qt_this = new(__qtjambi_ptr) QWebEngineFindTextResult();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QWebEngineFindTextResult(QWebEngineFindTextResult)
void __qt_construct_QWebEngineFindTextResult_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineFindTextResult(QWebEngineFindTextResult)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineFindTextResult& __qt_other0 = qtjambi_cast<const QWebEngineFindTextResult& >(__jni_env, other0);
    QWebEngineFindTextResult *__qt_this = new(__qtjambi_ptr) QWebEngineFindTextResult(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineFindTextResult
void __qt_destruct_QWebEngineFindTextResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineFindTextResult")
    reinterpret_cast<QWebEngineFindTextResult*>(ptr)->~QWebEngineFindTextResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineFindTextResult::QWebEngineFindTextResult()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_initialize_1native__Lio_qt_webengine_core_QWebEngineFindTextResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineFindTextResult::QWebEngineFindTextResult()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineFindTextResult_0, sizeof(QWebEngineFindTextResult), typeid(QWebEngineFindTextResult), false, &deleter_QWebEngineFindTextResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFindTextResult::QWebEngineFindTextResult(QWebEngineFindTextResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_initialize_1native__Lio_qt_webengine_core_QWebEngineFindTextResult_2Lio_qt_webengine_core_QWebEngineFindTextResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineFindTextResult::QWebEngineFindTextResult(QWebEngineFindTextResult)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineFindTextResult_1, sizeof(QWebEngineFindTextResult), typeid(QWebEngineFindTextResult), false, &deleter_QWebEngineFindTextResult, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFindTextResult::activeMatch()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_activeMatch_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::activeMatch()const", __qt_this)
        __java_return_value = __qt_this->activeMatch();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFindTextResult::numberOfMatches()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_numberOfMatches_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::numberOfMatches()const", __qt_this)
        __java_return_value = __qt_this->numberOfMatches();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFindTextResult::operator=(QWebEngineFindTextResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_assign_1native_1cref_1QWebEngineFindTextResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::operator=(QWebEngineFindTextResult)", __qt_this)
        const QWebEngineFindTextResult& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineFindTextResult>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFindTextResult::operator==(QWebEngineFindTextResult,QWebEngineFindTextResult)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_equals_1native_1cref_1QWebEngineFindTextResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFindTextResult::operator==(QWebEngineFindTextResult,QWebEngineFindTextResult)", __qt_this)
        const QWebEngineFindTextResult& __qt_arg21 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineFindTextResult>(arg21);
        __java_return_value = (*__qt_this) == __qt_arg21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFindTextResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineFindTextResult *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFindTextResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineFindTextResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineFindTextResult>("QWebEngineFindTextResult", "io/qt/webengine/core/QWebEngineFindTextResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineFindTextResult, {
        ConstructorInfo(&__qt_construct_QWebEngineFindTextResult_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QWebEngineFindTextResult_1, "Lio/qt/webengine/core/QWebEngineFindTextResult;")
    });
// END: function table

    registerMetaObject(typeId, QWebEngineFindTextResult::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineFindTextResult);
    registerMetaType<QWebEngineFindTextResult>("QWebEngineFindTextResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
